import { ExtendedTransactionBuilder } from "../transaction.js";
import TransactionBuilder from "../transaction_builder.js";
import { Service } from "../types.js";
import { AccountIdentity, ConnectionState, Endpoint, RpcRequestOrigin, RpcSubscription, TransactionSuccess } from "./types.js";
export declare class RpcRequest {
    private origin;
    private version;
    private payload;
    constructor(origin: RpcRequestOrigin, payload?: object, version?: number);
}
export declare enum AWCStreamChannelState {
    CONNECTING = 0,
    OPEN = 1,
    CLOSING = 2,
    CLOSED = 3
}
export interface AWCStreamChannel<T> {
    get state(): AWCStreamChannelState;
    connect(): Promise<void>;
    close(): Promise<void>;
    send(data: T): Promise<void>;
    onReceive: ((data: T) => Promise<void>) | null;
    onReady: (() => Promise<void>) | null;
    onClose: ((reason: string) => Promise<void>) | null;
}
export declare class ArchethicWalletClient {
    private origin;
    private client;
    private _channel;
    private _connectionStateEventTarget;
    private _rpcNotificationEventTarget;
    private static _instance;
    constructor(channel: AWCStreamChannel<string>);
    static init(channel: AWCStreamChannel<string>): void;
    static get instance(): ArchethicWalletClient;
    setOrigin(origin: RpcRequestOrigin): this;
    _dispatchConnectionState(state?: ConnectionState): void;
    connect(): Promise<void>;
    close(): Promise<void>;
    _ensuresConnectionAlive(): void;
    onAccountUpdate(accountName: string, listener: Function): PromiseLike<RpcSubscription> | undefined;
    _subscribe(method: string, data: object, listener: Function): PromiseLike<RpcSubscription> | undefined;
    unsubscribe(subscription: RpcSubscription): void;
    get connectionState(): ConnectionState;
    onconnectionstatechange(listener: (state: ConnectionState) => void): this;
    unsubscribeconnectionstatechange(): this;
    getEndpoint(): Promise<Endpoint>;
    sendTransaction(transaction: TransactionBuilder | ExtendedTransactionBuilder): Promise<TransactionSuccess>;
    signTransactions(serviceName: string, pathSuffix: string, transactions: TransactionBuilder[] | ExtendedTransactionBuilder[]): Promise<TransactionBuilder[] | ExtendedTransactionBuilder[]>;
    addService(name: string): Promise<TransactionSuccess>;
    getAccounts(): Promise<AccountIdentity[]>;
    getCurrentAccount(): Promise<AccountIdentity>;
    getServices(): Promise<Service[]>;
    keychainDeriveKeypair(serviceName: string, index?: number, pathSuffix?: string): Promise<{
        publicKey: string;
    }>;
    keychainDeriveAddress(serviceName: string, index?: number, pathSuffix?: string): Promise<{
        address: string;
    }>;
    onCurrentAccountChange(listener: Function): PromiseLike<RpcSubscription> | undefined;
    refreshCurrentAccount(): void;
}
