import { encryptSecret, deriveAddress } from "./crypto.js";
export function extractActionsFromContract(code) {
    const regex = /actions\s+triggered_by:\s+transaction,\s+on:\s+([\w\s.,()]+?)\s+do/g;
    let actions = [];
    for (const match of code.matchAll(regex)) {
        const fullAction = match[1];
        const regexActionName = /(\w+)\((.*?)\)/g;
        for (const actionMatch of fullAction.matchAll(regexActionName)) {
            const name = actionMatch[1];
            const parameters = actionMatch[2] != "" ? actionMatch[2].split(",") : [];
            actions.push({
                name: name,
                parameters: parameters
            });
        }
    }
    return actions;
}
export function parseTypedArgument(input) {
    if (typeof input === "object") {
        return input;
    }
    else if (!isNaN(input)) {
        return parseFloat(input);
    }
    else {
        return input;
    }
}
export async function newContractTransaction(archethic, code, seed) {
    const storageNoncePublicKey = await archethic.network.getStorageNoncePublicKey();
    const index = await archethic.transaction.getTransactionIndex(deriveAddress(seed, 0));
    const { encryptedSecret, authorizedKeys } = encryptSecret(seed, storageNoncePublicKey);
    return archethic.transaction
        .new()
        .setType("contract")
        .setCode(code)
        .addOwnership(encryptedSecret, authorizedKeys)
        .build(seed, index);
}
//# sourceMappingURL=contract.js.map