import { ConnectionState } from "./api/types.js";
import { AWCWebBrowserExtension } from "./api/wallet_rpc.browserextension.js";
import { ArchethicWalletClient } from "./api/wallet_rpc.js";
import { AWCWebsocketStreamChannel } from "./api/wallet_rpc.websocket.js";
export class EndpointFactory {
    build(endpoint) {
        if (endpoint === undefined) {
            console.log('Using AWC client');
            return new AWCEndpoint(AWCWebBrowserExtension.awc ??
                new ArchethicWalletClient(new AWCWebsocketStreamChannel(`ws://localhost:12345`)));
        }
        const url = new URL(endpoint);
        if (url.protocol === "http:" || url.protocol === "https:") {
            console.log('Using direct endpoint');
            return new DirectEndpoint(endpoint);
        }
        throw new Error(`Invalid endpoint protocol: ${url.protocol}`);
    }
}
export class DirectEndpoint {
    origin;
    nodeEndpoint;
    get isRpcAvailable() {
        return false;
    }
    constructor(endpoint) {
        this.origin = endpoint;
        this.nodeEndpoint = new URL(endpoint);
    }
}
export class AWCEndpoint {
    rpcClient;
    origin;
    _nodeEndpoint;
    get isRpcAvailable() {
        return true;
    }
    constructor(client) {
        this.rpcClient = client;
        this.origin = 'AWC';
        this._nodeEndpoint = null;
    }
    get nodeEndpoint() { return this._nodeEndpoint; }
    async resolve() {
        if (this.rpcClient.connectionState !== ConnectionState.Open) {
            await this.rpcClient.connect();
        }
        await this.rpcClient.getEndpoint().then((response) => {
            this._nodeEndpoint = new URL(response["endpointUrl"]);
        });
    }
}
//# sourceMappingURL=endpoint.js.map