import Account, { Keychain } from "./account.js";
import * as Api from "./api.js";
import { NodeRPCClient } from "./api/node_rpc.js";
import { ConnectionState } from "./api/types.js";
import { AWCStreamChannelState, ArchethicWalletClient } from "./api/wallet_rpc.js";
import * as Crypto from "./crypto.js";
import { AWCEndpoint, EndpointFactory } from "./endpoint.js";
import Network from "./network.js";
import Transaction from "./transaction.js";
import * as Contract from "./contract.js";
import * as Utils from "./utils.js";
export { AWCStreamChannelState, ArchethicWalletClient, ConnectionState, Crypto, Keychain, Utils, Contract };
export default class Archethic {
    endpoint;
    rpcWallet;
    rpcNode;
    transaction;
    nearestEndpoints;
    account;
    network;
    constructor(endpoint) {
        this.endpoint = new EndpointFactory().build(endpoint);
        if (this.endpoint instanceof AWCEndpoint) {
            this.rpcWallet = this.endpoint.rpcClient;
        }
        this.account = new Account(this);
        this.network = new Network(this);
        this.nearestEndpoints = new Set();
        this.transaction = new Transaction(this);
        this.rpcNode = new NodeRPCClient(this);
    }
    async connect() {
        if (this.endpoint instanceof AWCEndpoint) {
            await this.endpoint.resolve();
        }
        const nodes = this.endpoint.nodeEndpoint === null ?
            [] :
            await Api.getNearestEndpoints(this.endpoint.nodeEndpoint.toString());
        let nearestEndpoints = nodes.map(({ ip, port }) => {
            return `http://${ip}:${port}`;
        });
        nearestEndpoints.push(this.endpoint.origin.toString());
        this.nearestEndpoints = new Set(nearestEndpoints);
        return this;
    }
    async requestNode(call) {
        const node = this.nearestEndpoints.values().next().value;
        try {
            return await call(node);
        }
        catch (err) {
            this.nearestEndpoints.delete(node);
            if (this.nearestEndpoints.size == 0) {
                console.log(err);
                throw new Error("Cannot reach Archethic node");
            }
            return this.requestNode(call);
        }
    }
}
//# sourceMappingURL=index.js.map