export const originPrivateKey = "01019280BDB84B8F8AEDBA205FE3552689964A5626EE2C60AA10E3BF22A91A036009";
export function wordArrayToUint8Array(wordArray) {
    const dataArray = new Uint8Array(wordArray.sigBytes);
    for (let i = 0x0; i < wordArray.sigBytes; i++) {
        dataArray[i] = (wordArray.words[i >>> 0x2] >>> (0x18 - (i % 0x4) * 0x8)) & 0xff;
    }
    return new Uint8Array(dataArray);
}
export function isHex(str) {
    return /^[0-9a-fA-F]+$/.test(str);
}
export function isObject(variable) {
    return typeof variable === "object" && !Array.isArray(variable) && variable !== null;
}
export function sortObjectKeysASC(term) {
    if (Array.isArray(term))
        return term.map((item) => sortObjectKeysASC(item));
    if (term instanceof Map) {
        const sortedEntries = [...term.entries()].sort((a, b) => a[0].localeCompare(b[0]));
        const sortedMap = new Map(sortedEntries.map(([key, value]) => [key, sortObjectKeysASC(value)]));
        return sortedMap;
    }
    if (isObject(term))
        return Object.keys(term)
            .sort((a, b) => a.localeCompare(b))
            .reduce((newObj, key) => {
            newObj[key] = sortObjectKeysASC(term[key]);
            return newObj;
        }, {});
    return term;
}
export function hexToUint8Array(str) {
    if (!isHex(str)) {
        throw new Error("Invalid hex string");
    }
    return new Uint8Array(str.match(/.{1,2}/g).map((byte) => parseInt(byte, 0x10)));
}
export function maybeStringToUint8Array(str) {
    if (typeof str === "string") {
        if (isHex(str)) {
            str = hexToUint8Array(str);
        }
        else {
            str = new TextEncoder().encode(str);
        }
    }
    return str;
}
export function maybeHexToUint8Array(str) {
    if (typeof str === "string") {
        if (isHex(str)) {
            str = hexToUint8Array(str);
        }
        else {
            throw new Error("Invalid hex string");
        }
    }
    return str;
}
export function maybeUint8ArrayToHex(bytes) {
    if (bytes instanceof Uint8Array) {
        return uint8ArrayToHex(bytes);
    }
    return bytes;
}
export function intToUint8Array(int) {
    return toByteArray(int);
}
export function intToUint32Array(int) {
    const buffer = new ArrayBuffer(4);
    const view = new DataView(buffer);
    view.setUint32(0x0, int, true);
    return new Uint8Array(buffer).reverse();
}
export function intToUint64Array(int) {
    const buffer = new ArrayBuffer(8);
    const view = new DataView(buffer);
    view.setBigUint64(0x0, getBigNumber(int), true);
    return new Uint8Array(buffer).reverse();
}
export function uint8ArrayToBigInt(bytes) {
    return fromByteArray(bytes);
}
export function parseBigInt(number, formatDecimals = 8) {
    const match = number.match(/^([0-9]*)\.?([0-9]*)$/);
    if (!match || match[1].length + match[2].length == 0) {
        throw new Error("Invalid number");
    }
    let whole = match[1] || "0", decimal = match[2] || "";
    while (decimal.length < formatDecimals) {
        decimal += "0000";
    }
    decimal = decimal.substring(0, formatDecimals);
    return BigInt(whole + decimal);
}
export function getBigNumber(number) {
    switch (typeof number) {
        case "bigint":
            return number;
        case "number":
            if (!Number.isInteger(number)) {
                throw new Error(`${number} is not an integer`);
            }
            return BigInt(number);
        default:
            throw new Error(`${number} is not an valid number`);
    }
}
export function formatBigInt(number, formatDecimals = 8) {
    let strNumber = getBigNumber(number).toString();
    if (formatDecimals === 0) {
        return strNumber;
    }
    while (strNumber.length <= formatDecimals) {
        strNumber = "0000" + strNumber;
    }
    const index = strNumber.length - formatDecimals;
    strNumber = strNumber.substring(0, index) + "." + strNumber.substring(index);
    while (strNumber[0] === "0" && strNumber[1] !== ".") {
        strNumber = strNumber.substring(1);
    }
    while (strNumber[strNumber.length - 1] === "0" && strNumber[strNumber.length - 2] !== ".") {
        strNumber = strNumber.substring(0, strNumber.length - 1);
    }
    return strNumber;
}
export function concatUint8Arrays(...arrays) {
    let totalLength = 0;
    for (let arr of arrays) {
        totalLength += arr.length;
    }
    let result = new Uint8Array(totalLength);
    let offset = 0;
    for (let arr of arrays) {
        result.set(arr, offset);
        offset += arr.length;
    }
    return result;
}
export function uint8ArrayToHex(bytes) {
    return Array.from(bytes)
        .map((b) => b.toString(16).padStart(2, "0"))
        .join("");
}
const chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-_";
export function base64url(arraybuffer) {
    let bytes = new Uint8Array(arraybuffer), i, len = bytes.length, base64 = "";
    for (i = 0; i < len; i += 3) {
        base64 += chars[bytes[i] >> 2];
        base64 += chars[((bytes[i] & 3) << 4) | (bytes[i + 1] >> 4)];
        base64 += chars[((bytes[i + 1] & 15) << 2) | (bytes[i + 2] >> 6)];
        base64 += chars[bytes[i + 2] & 63];
    }
    if (len % 3 === 2) {
        base64 = base64.substring(0, base64.length - 1);
    }
    else if (len % 3 === 1) {
        base64 = base64.substring(0, base64.length - 2);
    }
    return base64;
}
function toByteArray(number) {
    var hex = getBigNumber(number).toString(16);
    if (hex.length % 2) {
        hex = "0" + hex;
    }
    var len = hex.length / 2;
    var u8 = new Uint8Array(len);
    var i = 0;
    var j = 0;
    while (i < len) {
        u8[i] = parseInt(hex.slice(j, j + 2), 16);
        i += 1;
        j += 2;
    }
    return u8;
}
function fromByteArray(bytes) {
    let hex = [];
    bytes.forEach(function (i) {
        var h = i.toString(16);
        if (h.length % 2) {
            h = "0" + h;
        }
        hex.push(h);
    });
    return BigInt("0x" + hex.join(""));
}
export function nextUint8(iter) {
    return iter.next().value[1];
}
export function serializeString(str) {
    return new TextEncoder().encode(str);
}
export function deserializeString(encoded_str) {
    return new TextDecoder().decode(encoded_str);
}
BigInt.prototype.toJSON = function () {
    return parseInt(this.toString());
};
//# sourceMappingURL=utils.js.map